@@ -7,13 +7,13 @@ import (
 	"context"
 	"regexp"
 
-	_ "github.com/uber/athenadriver/go" // DRIVER
+	_ "github.com/uber/athenadriver/go" // DRIVER: awsathena
 	"github.com/xo/usql/drivers"
 )
 
 func init() {
 	endRE := regexp.MustCompile(`;?\s*$`)
-	drivers.Register("athena", drivers.Driver{
+	drivers.Register("awsathena", drivers.Driver{
 		AllowMultilineComments: true,
 		Process: func(prefix string, sqlstr string) (string, string, bool, error) {
 			sqlstr = endRE.ReplaceAllString(sqlstr, "")
